@@ -1,10 +1,8 @@
-#!/usr/bin/env python
-
 # Tests for natural order sorting module.
 #
-# Author: Peter Odding <peter.odding@paylogic.eu>
-# Last Change: June 14, 2013
-# URL: https://pypi.python.org/pypi/naturalsort
+# Author: Peter Odding <peter@peterodding.com>
+# Last Change: November 16, 2013
+# URL: https://github.com/xolox/python-naturalsort
 
 # Standard library modules.
 import unittest
@@ -12,7 +10,7 @@ import unittest
 # The module we're testing.
 from natsort import natsort
 
-class PipAccelTestCase(unittest.TestCase):
+class NaturalSortTestCase(unittest.TestCase):
 
     def runTest(self):
 
@@ -22,5 +20,7 @@ class PipAccelTestCase(unittest.TestCase):
       # This is version sorting (what we're after).
       assert natsort(['1', '5', '10', '50']) == ['1', '5', '10', '50']
 
-      # This covers a previously fixed bug.
-      assert natsort(['1.0', '1.5']) == ['1.0', '1.5']
+      # This covers a previously fixed bug. I've purposefully shuffled the
+      # order on the left side to avoid false positives caused by stable
+      # sorting.
+      assert natsort(['1.5', '1.0']) == ['1.0', '1.5']
